Running unit tests
------------------

*Note: As of now, it is required that you run the configuration tool before the unit tests start working. This is something to be fixed.*

Run the shell script "run_tests.sh" to run all the unit tests in the software package.